@@ -4,7 +4,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2018 Pascal Buchbinder
+ * Copyright (C) 2019 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -29,8 +29,8 @@
 /* ----------------------------------
  * version info
  * ---------------------------------- */
-static const char man_version[] = "11.60";
-static const char man_date[] = "December 2018";
+static const char man_version[] = "11.62";
+static const char man_date[] = "March 2019";
 
 /* ----------------------------------
  * definitions
